import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * The ``postgresql.getSequences`` data source retrieves a list of sequence names from a specified PostgreSQL database.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const mySequences = postgresql.getSequences({
 *     database: "my_database",
 * });
 * ```
 */
export declare function getSequences(args: GetSequencesArgs, opts?: pulumi.InvokeOptions): Promise<GetSequencesResult>;
/**
 * A collection of arguments for invoking getSequences.
 */
export interface GetSequencesArgs {
    /**
     * The PostgreSQL database which will be queried for sequence names.
     */
    database: string;
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``LIKE ALL`` operators.
     */
    likeAllPatterns?: string[];
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``LIKE ANY`` operators.
     */
    likeAnyPatterns?: string[];
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``NOT LIKE ALL`` operators.
     */
    notLikeAllPatterns?: string[];
    /**
     * Expression which will be pattern matched against sequence names in the query using the PostgreSQL ``~`` (regular expression match) operator.
     *
     * Note that all optional arguments can be used in conjunction.
     */
    regexPattern?: string;
    /**
     * List of PostgreSQL schema(s) which will be queried for sequence names. Queries all schemas in the database by default.
     */
    schemas?: string[];
}
/**
 * A collection of values returned by getSequences.
 */
export interface GetSequencesResult {
    readonly database: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly likeAllPatterns?: string[];
    readonly likeAnyPatterns?: string[];
    readonly notLikeAllPatterns?: string[];
    readonly regexPattern?: string;
    readonly schemas?: string[];
    /**
     * A list of PostgreSQL sequences retrieved by this data source. Each sequence consists of the fields documented below.
     * ___
     */
    readonly sequences: outputs.GetSequencesSequence[];
}
/**
 * The ``postgresql.getSequences`` data source retrieves a list of sequence names from a specified PostgreSQL database.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const mySequences = postgresql.getSequences({
 *     database: "my_database",
 * });
 * ```
 */
export declare function getSequencesOutput(args: GetSequencesOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetSequencesResult>;
/**
 * A collection of arguments for invoking getSequences.
 */
export interface GetSequencesOutputArgs {
    /**
     * The PostgreSQL database which will be queried for sequence names.
     */
    database: pulumi.Input<string>;
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``LIKE ALL`` operators.
     */
    likeAllPatterns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``LIKE ANY`` operators.
     */
    likeAnyPatterns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of expressions which will be pattern matched against sequence names in the query using the PostgreSQL ``NOT LIKE ALL`` operators.
     */
    notLikeAllPatterns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Expression which will be pattern matched against sequence names in the query using the PostgreSQL ``~`` (regular expression match) operator.
     *
     * Note that all optional arguments can be used in conjunction.
     */
    regexPattern?: pulumi.Input<string>;
    /**
     * List of PostgreSQL schema(s) which will be queried for sequence names. Queries all schemas in the database by default.
     */
    schemas?: pulumi.Input<pulumi.Input<string>[]>;
}
